#!/usr/bin/python
#
# Copyright (C) 2021 Associated Universities, Inc. Washington DC, USA.
#
# This file is part of NRAO Workspaces.
#
# Workspaces is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# Workspaces is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with Workspaces.  If not, see <https://www.gnu.org/licenses/>.
# -*- coding: utf-8 -*-

from pathlib import Path

from setuptools import find_packages, setup

VERSION = open("productfetcher/_version.py").readlines()[-1].split()[-1].strip("\"'")
README = Path("README.md").read_text()

requires = [
    "marshmallow>=3.12.1,<3.13",
    "cx_Oracle>=8.1.0,<8.2",
    "sqlalchemy==1.4.46",
    "pika>=1.1,<2",
    "pycapo>=0.3.0,<1.0",
    "beautifulsoup4>=4.9.1,<5.0",
    "lxml>=4.3.2,<5.0",
    "psycopg2>=2.8.5,<3.0",
    "requests>=2.23,<2.30.0",
    "requests-mock",
    "marshmallow",
    "pex==2.1.119",
    "tqdm>=4.60.00,<4.61",
]

setup(
    name="ssa-" + Path().absolute().name,
    version=VERSION,
    description="NRAO Archive Data Fetcher Script",
    long_description=README,
    author="NRAO SSA Team",
    author_email="dms-ssa@nrao.edu",
    url="TBD",
    license="GPL",
    install_requires=requires,
    tests_require=["pytest", "pytest-resource-path", "requests-mock"],
    keywords=[],
    packages=find_packages(),
    classifiers=["Programming Language :: Python :: 3.10"],
    entry_points={
        "console_scripts": [
            "productfetcher = productfetcher.product_fetcher:main",
        ]
    },
)
